# Authors

The authors of beancount2ledger are:

* Martin Blais
* Martin Michlmayr

Martin Blais added `ledger` and `hledger` output in beancount's `bean-report`.  In July 2020, the conversion functionality was split out into beancount2ledger, which is now maintained by Martin Michlmayr.

We have also had contributions and input from:

* Alen Siljak (fixes)
* John Wiegley (help with compatibility with ledger)
* Marin Bernard (bug reports)
* Simon Michael (help with compatibility with hledger)
* Software in the Public Interest, Inc. (fixes)
* Vikas Rawal (bug reports)

Thank you to all contributors and users!

If you'd like to contribute to beancount2beancount, please see the [contributions information](contributing.md).

